#  pystock

[![Build Status](https://travis-ci.org/llazzaro/pystock.svg)](https://travis-ci.org/llazzaro/pystock) [![Coverage Status](https://coveralls.io/repos/llazzaro/pystock/badge.svg?branch=master&service=github)](https://coveralls.io/github/llazzaro/pystock?branch=master) [![Code Health](https://landscape.io/github/llazzaro/pystock/master/landscape.svg?style=flat)](https://landscape.io/github/llazzaro/pystock/master)

pystock is intuitive relational model implemented with SQLAlchemy.

To get started check

## Table of contents

* [Quick start](#quick-start)
* [Bugs and feature requests](#bugs-and-feature-requests)
* [Documentation](#documentation)
* [Creators](#creators)

## Quick start

Two options are available:

* Clone the repo: `git clone https://github.com/llazzaro/pystock.git`.
* Install with pip: pip install pystock

## Bugs and feature requests

Have a bug or a feature request? [please open a new issue](https://github.com/llazzaro/pystock/issues/new).


## Documentation

pystock's documentation, included in this repo in the root directory, is built with  and publicly hosted on read the docs. The docs may also be run locally.

### Running documentation locally


## Creators

**Leonardo Lazzaro**

* <https://www.lazzaro.com.ar>
* your name! 
